summaryrefslogtreecommitdiff
path: root/include/i2c_private.h
diff options
context:
space:
mode:
authorDossym Nurmukhanov <dossym@google.com>2020-12-12 04:41:45 +0000
committerCommit Bot <commit-bot@chromium.org>2020-12-12 20:39:35 +0000
commit8223f2d538f3d40b1a306661312201118a00dbd5 (patch)
treeb281082f44ca52ed8f596e9b67aa7fc8a6f810a1 /include/i2c_private.h
parent52863374ad592b80b24def9689856ecda2d645d0 (diff)
downloadchrome-ec-8223f2d538f3d40b1a306661312201118a00dbd5.tar.gz
COIL: Clean up controller/peripheral language in headers
BUG=none TEST=verify builds are still working BRANCH=none Signed-off-by: dossym@chromium.org Change-Id: I8925a7ffd3ab4e47dfed213438f601d673188259 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2588008 Reviewed-by: Daisuke Nojiri <dnojiri@chromium.org>
Diffstat (limited to 'include/i2c_private.h')
-rw-r--r--include/i2c_private.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/i2c_private.h b/include/i2c_private.h
index 8a92884c16..0759f86ef2 100644
--- a/include/i2c_private.h
+++ b/include/i2c_private.h
@@ -5,7 +5,7 @@
/*
* Private chipset-specific implementations that only accessible by
- * i2c_master.c. Don't include this directly unless you are implementing
+ * i2c_controller.c. Don't include this directly unless you are implementing
* these functions.
*/
#ifndef __CROS_EC_I2C_PRIVATE_H
@@ -21,7 +21,7 @@
* i2c_xfer().
*
* @param port Port to access
* @param slave_addr Slave device address
* @param out Data to send
* @param out_size Number of bytes to send
* @param in Destination buffer for received data
@@ -30,7 +30,7 @@
* @return EC_SUCCESS, or non-zero if error.
*/
int chip_i2c_xfer(const int port,
- const uint16_t slave_addr_flags,
+ const uint16_t addr_flags,
const uint8_t *out, int out_size,
uint8_t *in, int in_size, int flags);
@@ -21,7 +21,7 @@
*
* @param port Port to access
- * @param slave_addr Slave device address
+ * @param addr_flags Peripheral device address
* @param out Data to send
* @param out_size Number of bytes to send